.. Stirimango documentation master file, created by
   sphinx-quickstart on Fri Jul  2 21:47:50 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Stirimango's documentation!
======================================

.. include:: ../README.rst

Man Pages
=========

.. toctree::
   :maxdepth: 1

   manpages/stirimango.1

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

